/*
' Copyright (c) 2012 DotNetNuke Corporation
'  All rights reserved.
' 
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
' DEALINGS IN THE SOFTWARE.
' 
*/

using System;
using DotNetNuke.Services.Exceptions;
using System.Xml;

namespace DotNetNuke.Modules.GPHosting_DNN_Contact_Form
{

    /// -----------------------------------------------------------------------------
    /// <summary>
    /// The EditGPHosting_DNN_Contact_Form class is used to manage content
    /// 
    /// Typically your edit control would be used to create new content, or edit existing content within your module.
    /// The ControlKey for this control is "Edit", and is defined in the manifest (.dnn) file.
    /// 
    /// Because the control inherits from GPHosting_DNN_Contact_FormModuleBase you have access to any custom properties
    /// defined there, as well as properties from DNN such as PortalId, ModuleId, TabId, UserId and many more.
    /// 
    /// </summary>
    /// -----------------------------------------------------------------------------
    public partial class Edit : GPHosting_DNN_Contact_FormModuleBase
    {

        #region Event Handlers

        override protected void OnInit(EventArgs e)
        {
            InitializeComponent();
            base.OnInit(e);
        }

        private void InitializeComponent()
        {
            this.Load += new System.EventHandler(this.Page_Load);
        }

        /// -----------------------------------------------------------------------------
        /// <summary>
        /// Page_Load runs when the control is loaded
        /// </summary>
        /// -----------------------------------------------------------------------------
        private void Page_Load(object sender, System.EventArgs e)
        {
            try
            {
                //Implement your edit logic for your module

            }
            catch (Exception exc) //Module failed to load
            {
                Exceptions.ProcessModuleLoadException(this, exc);
            }


            if (!IsPostBack)
            {
                string site = PortalAlias.HTTPAlias.ToString();
                int pid = PortalId;
                int mid = ModuleId;
                string urlpath = Server.HtmlEncode(Request.PhysicalApplicationPath);
                string portalpath = "Portals\\" + pid.ToString();
                string xpath = urlpath.ToString() + portalpath.ToString() + "\\contactformdata-" + pid.ToString() + "-" + mid.ToString() + "-.xml";
                XmlDocument xdoc = new XmlDocument();
                xdoc.Load(xpath.ToString());
                string tomail = xdoc.GetElementsByTagName("tomail")[0].InnerText;
                string frommail = xdoc.GetElementsByTagName("frommail")[0].InnerText;
                string bccmail = xdoc.GetElementsByTagName("bccmail")[0].InnerText;
                string subject = xdoc.GetElementsByTagName("subject")[0].InnerText;
                string replysubject = xdoc.GetElementsByTagName("Replysubject")[0].InnerText;
                string reply = xdoc.GetElementsByTagName("reply")[0].InnerText;
                string replytext = xdoc.GetElementsByTagName("replytext")[0].InnerText;
                string showcaptcha = xdoc.GetElementsByTagName("showcaptcha")[0].InnerText;
                string UseDNNsmpt = xdoc.GetElementsByTagName("UseDNNsmpt")[0].InnerText;
                string SMTPServer = xdoc.GetElementsByTagName("SMTPServer")[0].InnerText;
                string SMTPUsername = xdoc.GetElementsByTagName("SMTPUsername")[0].InnerText;
                string SMTPPassword = xdoc.GetElementsByTagName("SMTPPassword")[0].InnerText;
                string SMTPPort = xdoc.GetElementsByTagName("SMTPPort")[0].InnerText;
                string SMTPSSL = xdoc.GetElementsByTagName("SMTPSSL")[0].InnerText;

                txtBCCMail.Text = bccmail.ToString();
                txtToMeail.Text = tomail.ToString();
                txtFromMail.Text = frommail.ToString();
                txtreplymail.Text = replytext.ToString();
                txtsmtpserver.Text = SMTPServer.ToString();
                txtsmtpusername.Text = SMTPUsername.ToString();
                txtsmtppassword.Text = SMTPPassword.ToString();
                txtsmtpport.Text = SMTPPort.ToString();
                txtreplysubject.Text = replysubject.ToString();
                txtSubject.Text = subject.ToString();

                if (reply == "1")
                {
                    chksendreply.Checked = true;

                }
                else
                {

                    chksendreply.Checked = false;
                }

                if (showcaptcha == "1")
                {
                    captcha.Checked = true;

                }
                else
                {

                    captcha.Checked = false;
                }
                if (UseDNNsmpt == "1")
                {
                    checkdnnsmtp.Checked = true;
                }
                else {
                    checkdnnsmtp.Checked = false;
                }
                if (SMTPSSL == "1")
                {
                    checkuseSSL.Checked = true;
                }
                else {
                    checkuseSSL.Checked = false;
                }
            }
        }

        #endregion

        protected void linkupdate_Click(object sender, EventArgs e)
        {
            if (IsPostBack)
            {
                int pid = PortalId;
                int mid = ModuleId;
                string urlpath = Server.HtmlEncode(Request.PhysicalApplicationPath);
                string portalpath = "Portals\\" + pid.ToString();
                string xpath = urlpath.ToString() + portalpath.ToString() + "\\contactformdata-" + pid.ToString() + "-" + mid.ToString() + "-.xml";
                XmlDocument xdoc = new XmlDocument();
                xdoc.Load(xpath);
                XmlNodeList nodelist = xdoc.SelectNodes("/contactformdb/contactsettings");
                nodelist[0].ChildNodes[0].InnerText = txtToMeail.Text.ToString();
                nodelist[0].ChildNodes[1].InnerText = txtFromMail.Text.ToString();
                nodelist[0].ChildNodes[2].InnerText = txtBCCMail.Text.ToString();
                nodelist[0].ChildNodes[3].InnerText = txtSubject.Text.ToString();
                nodelist[0].ChildNodes[4].InnerText = txtreplysubject.Text.ToString();
                nodelist[0].ChildNodes[7].InnerText = txtsmtpserver.Text.ToString();
                nodelist[0].ChildNodes[8].InnerText = txtsmtpusername.Text.ToString();
                nodelist[0].ChildNodes[9].InnerText = txtsmtppassword.Text.ToString();
                nodelist[0].ChildNodes[10].InnerText = txtsmtpport.Text.ToString();


                if (checkuseSSL.Checked == true)
                {
                    nodelist[0].ChildNodes[11].InnerText = "1";
                }
                else {
                    nodelist[0].ChildNodes[11].InnerText = "0";
                }

                if (checkdnnsmtp.Checked == true)
                {

                    nodelist[0].ChildNodes[6].InnerText = "1";
                }
                else
                {
                    nodelist[0].ChildNodes[6].InnerText = "0";
                }

                if (chksendreply.Checked == true)
                {
                    nodelist[0].ChildNodes[5].InnerText = "1";
                }
                else
                {
                    nodelist[0].ChildNodes[5].InnerText = "0";
                }

                if (captcha.Checked == true)
                {
                    nodelist[0].ChildNodes[12].InnerText = "1";
                }
                else
                {
                    nodelist[0].ChildNodes[12].InnerText = "0";
                }

                nodelist[0].ChildNodes[13].InnerText = txtreplymail.Text.ToString();

                xdoc.Save(xpath);
            }
        }
    }

}