/*
' Copyright (c) 2012  DotNetNuke Corporation
'  All rights reserved.
' 
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
' DEALINGS IN THE SOFTWARE.
' 
*/

using System;
using DotNetNuke.Services.Exceptions;
using DotNetNuke.Entities.Modules;
using DotNetNuke.Entities.Modules.Actions;
using DotNetNuke.Services.Localization;
using DotNetNuke.Security;
using System.Xml;
using System.Text;
using System.Net.Mail;
using System.IO;


namespace DotNetNuke.Modules.GPHosting_DNN_Contact_Form
{

    /// -----------------------------------------------------------------------------
    /// <summary>
    /// The View class displays the content
    /// 
    /// Typically your view control would be used to display content or functionality in your module.
    /// 
    /// View may be the only control you have in your project depending on the complexity of your module
    /// 
    /// Because the control inherits from GPHosting_DNN_Contact_FormModuleBase you have access to any custom properties
    /// defined there, as well as properties from DNN such as PortalId, ModuleId, TabId, UserId and many more.
    /// 
    /// </summary>
    /// -----------------------------------------------------------------------------
    public partial class View : GPHosting_DNN_Contact_FormModuleBase, IActionable
    {
        string useDNNsmtp;
        string SmtpServer;
        string SmtpUsername;
        string SMtpPassword;
        string SmtpPort;
        string useSSL;

        #region Event Handlers

        override protected void OnInit(EventArgs e)
        {
            InitializeComponent();
            base.OnInit(e);
        }

        private void InitializeComponent()
        {
            this.Load += new System.EventHandler(this.Page_Load);
        }


        /// -----------------------------------------------------------------------------
        /// <summary>
        /// Page_Load runs when the control is loaded
        /// </summary>
        /// -----------------------------------------------------------------------------
        private void Page_Load(object sender, System.EventArgs e)
        {
            try
            {
                int pid = PortalId;
                int mid = ModuleId;
                string path = Server.HtmlEncode(Request.PhysicalApplicationPath);
                string portalpath = "Portals\\" + pid.ToString();
                // Create a new XmlTextWriter instance
                string xpath = path.ToString() + portalpath.ToString() + "\\contactformdata-" + pid.ToString() + "-" + mid.ToString() + "-.xml";
                FileStream fs = null;
                if (!File.Exists(xpath))
                {

                    XmlTextWriter writer = new
                     XmlTextWriter(xpath.ToString(), Encoding.UTF8);

                    // start writing!
                    writer.WriteStartDocument();
                    writer.Formatting = Formatting.Indented;
                    writer.WriteStartElement("contactformdb");
                    writer.WriteStartElement("contactsettings", "");
                    writer.WriteElementString("tomail", PortalSettings.Email.ToString());
                    writer.WriteElementString("frommail", PortalSettings.Email.ToString());
                    writer.WriteElementString("bccmail", PortalSettings.Email.ToString());
                    writer.WriteElementString("subject", "Add your Subject");
                    writer.WriteElementString("Replysubject", "Add your auto reply Subject");
                    writer.WriteElementString("reply", "1");
                    writer.WriteElementString("UseDNNsmpt", "1");
                    writer.WriteElementString("SMTPServer", "smtp.yourserver.com");
                    writer.WriteElementString("SMTPUsername", "smtpUsername");
                    writer.WriteElementString("SMTPPassword", "smtpPassword");
                    writer.WriteElementString("SMTPPort", "25");
                    writer.WriteElementString("SMTPSSL", "0");
                    writer.WriteElementString("showcaptcha", "1");
                    writer.WriteElementString("replytext", "Thank you for contacting me");
                    writer.WriteEndElement();
                    // Creating the <browserInfo> element

                    writer.Close();


                }
                string pathcaptcha = Server.HtmlEncode(Request.PhysicalApplicationPath);
                string portalpathcaptcha = "Portals\\" + pid.ToString();
                string xpathcaptcha = path.ToString() + portalpath.ToString() + "\\contactformdata-" + pid.ToString() + "-" + mid.ToString() + "-.xml";
                XmlDocument xdoc = new XmlDocument();
                xdoc.Load(xpath.ToString());
                string captchatrue = xdoc.GetElementsByTagName("showcaptcha")[0].InnerText;
                useDNNsmtp = xdoc.GetElementsByTagName("UseDNNsmpt")[0].InnerText;
                SmtpServer = xdoc.GetElementsByTagName("SMTPServer")[0].InnerText;
                SmtpUsername = xdoc.GetElementsByTagName("SMTPUsername")[0].InnerText;
                SMtpPassword = xdoc.GetElementsByTagName("SMTPPassword")[0].InnerText;
                SmtpPort = xdoc.GetElementsByTagName("SMTPPort")[0].InnerText;
                useSSL = xdoc.GetElementsByTagName("SMTPSSL")[0].InnerText;
                if (captchatrue == "0")
                {
                    showcaptcha.Visible = false;

                }
                else
                {
                    showcaptcha.Visible = true;
                }
                if (UserId.ToString() != "-1")
                {
                    txtname.Text = UserInfo.FirstName;
                    txtsurname.Text = UserInfo.LastName;
                    txtemail.Text = UserInfo.Email;


                }
                string rootpath = Server.MapPath("''");
                if (!Page.IsPostBack)
                {



                }
            }
            catch (Exception exc) //Module failed to load
            {
                Exceptions.ProcessModuleLoadException(this, exc);
            }
            
        }
         

        #endregion

        #region Optional Interfaces

        public ModuleActionCollection ModuleActions
        {
            get
            {
                ModuleActionCollection Actions = new ModuleActionCollection();
                Actions.Add(GetNextActionID(), Localization.GetString("EditModule", this.LocalResourceFile), "", "", "", EditUrl(), false, SecurityAccessLevel.Edit, true, false);
                return Actions;
            }
        }

        #endregion

        protected void btnsubmit_Click(object sender, EventArgs e)
        {
            if (IsPostBack)
            {
                string email = txtemail.Text.ToString();
                int pid = PortalId;
                int mid = ModuleId;
                string path = Server.HtmlEncode(Request.PhysicalApplicationPath);
                string portalpath = "Portals\\" + pid.ToString();
                string xpath = path.ToString() + portalpath.ToString() + "\\contactformdata-" + pid.ToString() + "-" + mid.ToString() + "-.xml";
                XmlDocument xdoc = new XmlDocument();
                xdoc.Load(xpath.ToString());
                string tomail = xdoc.GetElementsByTagName("tomail")[0].InnerText;
                string frommail = xdoc.GetElementsByTagName("frommail")[0].InnerText;
                string bccmail = xdoc.GetElementsByTagName("bccmail")[0].InnerText;
                string subject = xdoc.GetElementsByTagName("subject")[0].InnerText;
                string replysubject = xdoc.GetElementsByTagName("Replysubject")[0].InnerText;
                string replytext = xdoc.GetElementsByTagName("replytext")[0].InnerText;
                string reply = xdoc.GetElementsByTagName("reply")[0].InnerText;
                string showcap = xdoc.GetElementsByTagName("showcaptcha")[0].InnerText;
                string UseDNNsmpt = xdoc.GetElementsByTagName("UseDNNsmpt")[0].InnerText;
                string SMTPServer = xdoc.GetElementsByTagName("SMTPServer")[0].InnerText;
                string SMTPUsername = xdoc.GetElementsByTagName("SMTPUsername")[0].InnerText;
                string SMTPPassword = xdoc.GetElementsByTagName("SMTPPassword")[0].InnerText;
                string SMTPPort = xdoc.GetElementsByTagName("SMTPPort")[0].InnerText;
                string SMTPSSL = xdoc.GetElementsByTagName("SMTPSSL")[0].InnerText;
                

                if (showcap == "1")
                {
                    if (contactcaptcha.IsValid)
                    {
                        if (string.IsNullOrEmpty(bccmail)) { bccmail = "N/A"; }
                        if (SendEmail(tomail, frommail, bccmail, subject))
                        {
                            lblmsg.Text = "Message Sent Successful ";
                            if (reply.ToString() == "1")
                            {
                                if (SendReplyMail(frommail, replytext, replysubject))
                                {
                                    lblmsg.Text = "Message Sent Successful ";
                                    return;
                                }
                                else
                                {
                                    lblmsg.Text = "Message could not be sent<br /> the site admin has been notified";
                                    return;
                                }
                            }
                            return;
                        }
                        else
                        {
                            lblmsg.Text = "Message could not be sent<br /> the site admin has been notified";
                            return;
                        }

                    }
                    else { lblmsg.Text = "Captcha Field Invalid"; }
                    return;
                }
                else
                {

                    if (showcap == "0")
                    {
                        if (SendEmail(tomail, frommail, bccmail,subject))
                        {
                            lblmsg.Text = "Message Sent Successful ";
                            if (reply.ToString() == "1")
                            {
                                if (SendReplyMail(frommail, replytext, replysubject))
                                {
                                    lblmsg.Text = "Message Sent Successful ";
                                    return;
                                }
                                else
                                {
                                    lblmsg.Text = "Message could not be sent<br /> the site admin has been notified";
                                    return;
                                }
                            }
                            return;
                        }
                        else
                        {
                            lblmsg.Text = "Message could not be sent<br /> the site admin has been notified";
                            return;
                        }

                    }

                }



            }
        }

        public bool SendEmail(string _toAddress, string _fromAddress, string bccAddress, string subject)
        {

            try
            {
                //Create stringbuilder to build email body
                StringBuilder strMail = new StringBuilder();

                //Create Body for Email
                strMail.Append("<table width=\"600px\" cellpadding=\"3\" cellspacing=\"3\">");
                strMail.Append("<tr><td valign=\"top\" style=\"font-size:11pt;font-family:Arial;\">Name: " + txtname.Text.ToString() + "</td></tr>");
                strMail.Append("<tr><td valign=\"top\" style=\"font-size:11pt;font-family:Arial;\">Surname: " + txtsurname.Text.ToString() + "</td></tr>");
                strMail.Append("<tr><td valign=\"top\" style=\"font-size:11pt;font-family:Arial;\">Contact No.: " + txtcontactno.Text.ToString() + "</td></tr>");
                strMail.Append("<tr><td valign=\"top\" style=\"font-size:11pt;font-family:Arial;\">Email: " + txtemail.Text.ToString() + "</td></tr>");
                strMail.Append("<tr><td valign=\"top\" style=\"font-size:11pt;font-family:Arial;\">Message: <br /> <br /> " + txtmessage.Text.ToString() + "</td></tr>");
                strMail.Append("</table>");
                strMail.Append("<br />");
                strMail.Append("You may reply to this email by clicking on the reply button on your email application");



                DotNetNuke.Entities.Portals.PortalInfo portalinfo = new DotNetNuke.Entities.Portals.PortalInfo();
                string smtppass =null;
                string smtpuser =null;
                string smtpserver = null;
                string owneremail = PortalSettings.Email.ToString();
                string sitename = PortalSettings.PortalAlias.HTTPAlias.ToString();
                if (useDNNsmtp == "1")
                {
                     smtpserver = DotNetNuke.Entities.Host.Host.SMTPServer.ToString();
                     smtpuser = DotNetNuke.Entities.Host.Host.SMTPUsername.ToString();
                     smtppass = DotNetNuke.Entities.Host.Host.SMTPPassword.ToString();

                }
                else {
                    smtpserver = SmtpServer;
                    smtpuser = SmtpUsername;
                    smtppass = SMtpPassword;
                }
                //  string subject = txtsubject.Text.ToString();
                // string email = txtemail.Text.ToString();


                //Create Mail Object
                MailMessage mail = new MailMessage();

                //Create To Address
                MailAddress To = new MailAddress(_toAddress.ToString());
                //MailAddress To = new MailAddress("wesley@icode.co.za");

                //Create From Address
                MailAddress FromA = new MailAddress(txtemail.Text.ToString());

                //Create Reply Address
                MailAddress replytosender = new MailAddress(txtemail.Text.ToString());

                //Create Bcc Address
                if (bccAddress.ToString() != "N/A")
                {
                    MailAddress bcc = new MailAddress(bccAddress.ToString());
                    if (!string.IsNullOrEmpty(bccAddress.ToString()))
                    {

                        mail.Bcc.Add(bcc);
                    }
                }
                //Set Email to HTML Body
                mail.IsBodyHtml = true;
                

                //Subject
                mail.Subject = subject.ToString();// + subject.ToString();

                //Add To Recipients
                mail.To.Add(To);

                //Add Sender
                mail.From = FromA;

                //Add Body Text
                mail.Body = strMail.ToString();

                //Add Bcc

                //Add Reply Address
                mail.ReplyTo = new MailAddress(txtemail.Text.ToString());

                //SMTP Information
                //SmtpClient SmtpMail = new SmtpClient("smtp.icodemail.com");
                SmtpClient SmtpMail = new SmtpClient(smtpserver.ToString());

                //Send Email
                SmtpMail.Port = Convert.ToInt32(SmtpPort);
                if (useSSL == "1")
                {
                    SmtpMail.EnableSsl = true;
                }
                SmtpMail.Credentials = new System.Net.NetworkCredential(smtpuser, smtppass);
                
                SmtpMail.Send(mail);
                mail.Dispose();
                return true;

            }


            catch (Exception SendError)
            {
                DotNetNuke.Services.Log.EventLog.LogInfo loginfo = new Services.Log.EventLog.LogInfo();
                string date = DateTime.Now.ToString();
                DotNetNuke.Services.Log.EventLog.ExceptionLogController error1 = new Services.Log.EventLog.ExceptionLogController();

                loginfo.AddProperty("Contact Form Error", SendError.ToString());
                loginfo.LogPortalID = PortalId;
                loginfo.LogPortalName = PortalAlias.ToString();
                loginfo.LogTypeKey = DotNetNuke.Services.Log.EventLog.ExceptionLogController.ExceptionLogType.GENERAL_EXCEPTION.ToString();

                error1.AddLog(loginfo);

                return false;
            }
        }

        public bool SendReplyMail(string _ReplyFrom, string _ReplyText,string _replysubject)
        {
            try
            {
                string smtpuserReply;
                string smtppassReply;
                string smtpserver;
                if (useDNNsmtp == "0")
                {
                    smtpuserReply = SmtpUsername;
                    smtppassReply = SMtpPassword;
                    smtpserver = SmtpServer;
                }
                else {
                 smtpuserReply = DotNetNuke.Entities.Host.Host.SMTPUsername.ToString();
                  smtppassReply = DotNetNuke.Entities.Host.Host.SMTPPassword.ToString();
                 smtpserver = DotNetNuke.Entities.Host.Host.SMTPServer.ToString();
                }
                MailMessage mailreply = new MailMessage();
                MailAddress ToUser = new MailAddress(txtemail.Text.ToString());
                SmtpClient SmtpMailReply = new SmtpClient(smtpserver.ToString());
                string replyfrom = _ReplyFrom.ToString();
                mailreply.To.Add(ToUser);
                mailreply.From = new MailAddress(replyfrom);
                mailreply.Subject = _replysubject.ToString();
                mailreply.IsBodyHtml = true;

                string[] htmlEntity = { "&lt;", "&gt;", "&amp;", "&quot;" };
                string[] htmlreplace = { "<", ">", "&", "'" };

                string cleanhtml = "";
                for (int i = 0; i < 4; i++)
                {
                    cleanhtml = _ReplyText.Replace(htmlEntity[i], htmlreplace[i]);
                    _ReplyText = cleanhtml;
                }

                StringBuilder strMailreply = new StringBuilder();
                string htmlcleanleft = _ReplyText.ToString();
                string cleanhtmlnew = htmlcleanleft.Replace("&lt;", "<");
                string htmlcleanright = cleanhtmlnew.ToString();
                string mailreplybody = cleanhtmlnew.Replace("&gt;", ">");
                strMailreply.Append("<html>");
                strMailreply.Append("<head>");
                strMailreply.Append("</head>");
                strMailreply.Append("<body>");
                strMailreply.Append(cleanhtml.ToString());
                strMailreply.Append("</body>");
                strMailreply.Append("</html>");
                mailreply.Body = strMailreply.ToString();
                SmtpMailReply.Credentials = new System.Net.NetworkCredential(smtpuserReply, smtppassReply);
                SmtpMailReply.Send(mailreply);

                mailreply.Dispose();
                return true;
            }


            catch (Exception replyError)
            {


                DotNetNuke.Services.Log.EventLog.LogInfo loginfo = new Services.Log.EventLog.LogInfo();
                string date = DateTime.Now.ToString();
                DotNetNuke.Services.Log.EventLog.ExceptionLogController error1 = new Services.Log.EventLog.ExceptionLogController();
                loginfo.LogTypeKey = DotNetNuke.Services.Log.EventLog.ExceptionLogController.ExceptionLogType.GENERAL_EXCEPTION.ToString();
                loginfo.AddProperty("Contact Form Error", replyError.ToString());
                loginfo.LogPortalID = PortalId;
                loginfo.LogPortalName = PortalAlias.ToString();
                error1.AddLog(loginfo);

                return false;

            }


        }

    }

}
